@@ -425,8 +425,7 @@ class AgentLifeCycle:
                 Returns:
                         result (bool): True if succeeded
         """
-        sts = subprocess.Popen(
-            "systemctl stop datadog-agent", shell=True).wait()
+        sts = subprocess.call(['sudo','sh','-c', 'systemctl stop datadog-agent'] )
         print("Health monitor agent stopped")
         return True
 
@@ -439,8 +438,7 @@ class AgentLifeCycle:
                 Returns:
                         result (bool): True if succeeded
         """
-        sts = subprocess.Popen(
-            "systemctl start datadog-agent", shell=True).wait()
+        sts = subprocess.call(['sudo','sh','-c', 'systemctl start datadog-agent'])
         print("Health monitor agent started")
         return True
 
@@ -453,8 +451,8 @@ class AgentLifeCycle:
                 Returns:
                         result (bool): True if succeeded
         """
-        sts = subprocess.Popen(
-            ["systemctl status datadog-agent", "-p"], shell=True, stdout=DEVNULL, stderr=DEVNULL).wait()
+        sts = subprocess.call(
+            ['sudo','sh','-c',"systemctl status datadog-agent", "-p"], shell=True, stdout=DEVNULL, stderr=DEVNULL)
         if sts == 0:
             print("Health monitor status:" +
                   bcolors.OKBLUE + " ACTIVE" + bcolors.ENDC)
